@@ -1,4 +1,4 @@
-use nettu_scheduler_domain::{Calendar, CalendarSettings, Metadata, SyncedCalendar, ID};
+use nettu_scheduler_domain::{Calendar, CalendarSettings, Metadata, Tz, Weekday, ID};
 use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Deserialize, Serialize, Clone)]
@@ -7,15 +7,14 @@ pub struct CalendarDTO {
     pub id: ID,
     pub user_id: ID,
     pub settings: CalendarSettingsDTO,
-    pub synced: Vec<SyncedCalendar>,
     pub metadata: Metadata,
 }
 
 #[derive(Debug, Deserialize, Serialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct CalendarSettingsDTO {
-    pub week_start: isize,
-    pub timezone: String,
+    pub week_start: Weekday,
+    pub timezone: Tz,
 }
 
 impl CalendarDTO {
@@ -24,7 +23,6 @@ impl CalendarDTO {
             id: calendar.id.clone(),
             user_id: calendar.user_id.clone(),
             settings: CalendarSettingsDTO::new(&calendar.settings),
-            synced: calendar.synced,
             metadata: calendar.metadata,
         }
     }
@@ -34,7 +32,7 @@ impl CalendarSettingsDTO {
     pub fn new(settings: &CalendarSettings) -> Self {
         Self {
             week_start: settings.week_start,
-            timezone: settings.timezone.to_string(),
+            timezone: settings.timezone,
         }
     }
 }
